pub const DENOMINATOR_SPACE: u8 = ' ' as u8;
pub const DENOMINATOR_NEW_LINE: u8 = '\n' as u8;
pub const DENOMINATOR_TAB: u8 = '\t' as u8;

pub const DENOMINATOR_COMMENT: u8 = '/' as u8;
pub const DENOMINATOR_COMMENT_CONTINUOUS: u8 = '*' as u8;
pub const DENOMINATOR_COMMENT_LINE: u8 = '/' as u8;

pub const DENOMINATOR_DECLARATION: u8 = ':' as u8;
pub const DENOMINATOR_SEPARATOR: u8 = ',' as u8;

pub const DENOMINATOR_ARGUMENT_START: u8 = '(' as u8;
pub const DENOMINATOR_ARGUMENT_END: u8 = ')' as u8;
pub const DENOMINATOR_DATA_START: u8 = '{' as u8;
pub const DENOMINATOR_DATA_END: u8 = '}' as u8;
pub const DENOMINATOR_LIST_START: u8 = '[' as u8;
pub const DENOMINATOR_LIST_END: u8 = ']' as u8;

pub const DENOMINATOR_CHAR: u8 = '\'' as u8;
pub const DENOMINATOR_STRING: u8 = '"' as u8;
